sequencetools.partition_sequence_cyclically_by_counts_without_overhang
======================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_cyclically_by_counts_without_overhang.partition_sequence_cyclically_by_counts_without_overhang
